package com.dgtly.system.service;

import com.dgtly.system.domain.Community;
import java.util.List;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author dgtly
 * @date 2020-02-14
 */
public interface ICommunityService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public Community selectCommunityById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param community 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<Community> selectCommunityList(Community community);

    /**
     * 新增【请填写功能名称】
     * 
     * @param community 【请填写功能名称】
     * @return 结果
     */
    public int insertCommunity(Community community);

    /**
     * 修改【请填写功能名称】
     * 
     * @param community 【请填写功能名称】
     * @return 结果
     */
    public int updateCommunity(Community community);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCommunityByIds(String ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteCommunityById(Long id);
}
